@@ -1,6 +1,6 @@
 # btssoap.rb - ruby interface for Debian BTS SOAP engine
 # Copyright (C) 2006-2008  Junichi Uekawa <dancer@debian.org>
-# Copyright (C) 2009-2020  Francesco Poli <invernomuto@paranoici.org>
+# Copyright (C) 2009-2022  Francesco Poli <invernomuto@paranoici.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,9 +12,10 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License with
+# the Debian GNU/Linux distribution in file /usr/share/common-licenses/GPL-2;
+# if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 require 'soap/rpc/driver'
 require 'aptlistbugs/debian/bug'
@@ -57,39 +58,44 @@ module Debian
         else
           $stderr.puts "fetching #{sa.join(" ")}.. " if $DEBUG
           # get the SOAP driver to send 'get_status'
-          @drv.get_status(sa).each { |bugnum, res|
-            # parse the received information, given from the server
-            $stderr.puts res.inspect if $DEBUG
-            if ma_copies.nil?
-              packages = [res.package]
-            else
-              packages = res.package.split(/[ \t?,()]+/)
-            end
-            packages.each { |pkg_name|
+          retval = @drv.get_status(sa)
+          if ! retval.kind_of?(Hash)
+            $stderr.puts "Unknown to the BTS: #{sa.join(" ")}" if $DEBUG
+          else
+            retval.each { |bugnum, res|
+              # parse the received information, given from the server
+              $stderr.puts res.inspect if $DEBUG
               if ma_copies.nil?
-                keys = [pkg_name]
+                packages = [res.package]
               else
-                keys = ma_copies[pkg_name]
-              end
-              if ( keys != nil )
-                keys.each { |pkg_key|
-                  newbug = Debian::Bug.new(pkg_key,
-                                           bugnum.to_s,
-                                           res.severity,
-                                           res.pending,
-                                           res.subject.gsub(/\r/,''),
-                                           res.tags.split(" "),
-                                           res.mergedwith.to_s.split(" "),
-                                           Time::at(res.date.to_i))
-                  newbug.found =
-                     res.found.keys.join(" ") if res.found.kind_of?(Hash)
-                  newbug.fixed =
-                     res.fixed.keys.join(" ") if res.fixed.kind_of?(Hash)
-                  get_status << newbug
-                }
+                packages = res.package.split(/[ \t?,()]+/)
               end
+              packages.each { |pkg_name|
+                if ma_copies.nil?
+                  keys = [pkg_name]
+                else
+                  keys = ma_copies[pkg_name]
+                end
+                if ( keys != nil )
+                  keys.each { |pkg_key|
+                    newbug = Debian::Bug.new(pkg_key,
+                                             bugnum.to_s,
+                                             res.severity,
+                                             res.pending,
+                                             res.subject.gsub(/\r/,''),
+                                             res.tags.split(" "),
+                                             res.mergedwith.to_s.split(" "),
+                                             Time::at(res.date.to_i))
+                    newbug.found =
+                       res.found.keys.join(" ") if res.found.kind_of?(Hash)
+                    newbug.fixed =
+                       res.fixed.keys.join(" ") if res.fixed.kind_of?(Hash)
+                    get_status << newbug
+                  }
+                end
+              }
             }
-          }
+          end
         end
         get_status
       end
